@@ -143,9 +143,7 @@ def test_local_fews_config(fews_config_local):
         try:
             fews_config.get_locations(location_set_key=loc_set)
         except Exception as err:
-            logger.error(
-                f"got error in get_locations() for loc_set {loc_set}, err={err}"
-            )
+            logger.error(f"got error in get_locations() for loc_set {loc_set}, err={err}")
 
     # test FewsConfigReader parameters (special case that works different for old configs and new configs)
     df_parameters = fews_config_local.get_parameters()
@@ -179,9 +177,7 @@ def test_github_fews_config_prd():
         try:
             fews_config.get_locations(location_set_key=loc_set)
         except Exception as err:
-            logger.error(
-                f"got error in get_locations() for loc_set {loc_set}, err={err}"
-            )
+            logger.error(f"got error in get_locations() for loc_set {loc_set}, err={err}")
 
     # test FewsConfigReader parameters (special case that works different for old configs and new configs)
     df_parameters = fews_config.get_parameters()
